# DataAnalysts Package

**DataAnalysts** is a Python library designed to simplify and streamline data analysis tasks, including data cleaning, transformation, and visualization. Whether you're a student, a data analyst, or a researcher, this package is built to handle datasets efficiently and interactively.

---

## 🚀 **Key Features**
- **Data Cleaning:**
  - Handle missing values (mean, median, mode strategies).
  - Remove duplicates, manage outliers, and preprocess raw datasets.
- **Data Transformation:**
  - Scale (standard, min-max, robust) and normalize datasets.
  - Encode categorical data and apply dimensionality reduction (PCA).
- **Data Visualization:**
  - Generate professional plots: Histogram, Line Plot, Scatter Plot, Heatmap, Pair Plot, Box Plot, Violin Plot.
  - Supports interactive and customizable visualizations.
- **Data Loading:**
  - Easily load datasets from CSV and Excel files.
- **Error Handling:**
  - Robust exception handling with clear error messages.
- **Interactive Tools:**
  - Interactive cleaning, transformation, and plotting tools for hands-on data analysis.

---

## 🛠️ **Installation Steps**

### **1. Install the Package from PyPI**
To use the library in Google Colab or your local environment, install it directly from PyPI:

```bash
pip install dataanalysts
```

---

## 💡 **Usage Examples**

### **1. Import the Library**
```python
import dataanalysts as da
import pandas as pd
```

### **2. Load Data**
```python
df = da.load_csv('data.csv')
df_excel = da.load_excel('data.xlsx', sheet_name='Sheet1')
```

### **3. Data Cleaning**
```python
df_cleaned = da.clean(df)
df_cleaned_outliers = da.clean(df, handle_outliers=True)
df_interactive_clean = da.interactive_clean(df)
```

### **4. Data Transformation**
```python
df_transformed = da.transform(df, strategy='standard')
df_pca = da.transform(df_transformed, reduce_dimensionality=True, n_components=3)
df_interactive_transform = da.interactive_transform(df)
```

### **5. Data Visualization**
```python
da.histogram(df, column='age', bins=30, kde=True)
da.barchart(df, x_col='city', y_col='population')
da.linechart(df, x_col='date', y_col='sales')
da.scatter(df, x_col='height', y_col='weight', hue='gender')
da.heatmap(df)
da.pairplot(df, hue='category')
da.boxplot(df, x_col='region', y_col='sales')
da.violinplot(df, x_col='region', y_col='sales')
```

### **6. Interactive Visualization**
```python
da.interactive_plot(df)
```

---

## 🤝 **Contributing**
Contributions are welcome! Please submit a pull request via our GitHub Repository.

---

## 📜 **License**
This project is licensed under the MIT License. See the LICENSE file for details.

---

## 🛠️ **Support**
If you encounter any issues, feel free to open an issue on our GitHub Issues page.

